@@ -21,15 +21,14 @@
 #ifndef OPTIONSDIALOG_H
 #define OPTIONSDIALOG_H
 
-#include <kpagedialog.h>
-
-#include <QtCore/QObject>
+#include <KPageDialog>
 
 #include "ui_preferencesui.h"
-#include "texttospeechconfigurationwidget.h"
 
-class KTabWidget;
+class QTabWidget;
 class KCModule;
+class TextToSpeechSystem;
+class TextToSpeechConfigurationWidget;
 class WordCompletionWidget;
 
 /**This class represents a configuration widget for user preferences.
@@ -43,8 +42,8 @@ public:
     PreferencesWidget(QWidget *parent, const char *name);
     ~PreferencesWidget();
 
-    void readOptions(KConfig *config);
-    void saveOptions(KConfig *config);
+    void readOptions();
+    void saveOptions();
 
     void ok();
     void cancel();
@@ -69,8 +68,8 @@ public:
 
     TextToSpeechSystem *getTTSSystem() const;
 
-    void readOptions(KConfig *config);
-    void saveOptions(KConfig *config);
+    void readOptions();
+    void saveOptions();
 
     bool isSpeakImmediately();
 
@@ -83,14 +82,10 @@ private slots:
     void slotApply();
 
 private:
-    KTabWidget *tabCtl;
+    QTabWidget *tabCtl;
     TextToSpeechConfigurationWidget *commandWidget;
     PreferencesWidget *behaviourWidget;
-    KCModule *kttsd;
     WordCompletionWidget *completionWidget;
-
-    KCModule *loadKttsd();
-    void unloadKttsd();
 };
 
 #endif
